==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GeographicShapeSeriesBaseBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapSeriesHostDescriptionMetadata } from "./GeographicMapSeriesHostDescriptionMetadata";
/**
 * @hidden
 */
export let GeographicShapeSeriesBaseBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicShapeSeriesBaseBaseDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicShapeSeriesBaseBaseDescriptionMetadata.a == null) {
                GeographicShapeSeriesBaseBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicShapeSeriesBaseBaseDescriptionMetadata.c(GeographicShapeSeriesBaseBaseDescriptionMetadata.a);
            }
            if (a.k(GeographicShapeSeriesBaseBaseDescriptionMetadata.a)) {
                return;
            }
            a.ab(GeographicShapeSeriesBaseBaseDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMapSeriesHostDescriptionMetadata.c(a);
        }
        static d(a) {
            GeographicShapeSeriesBaseBaseDescriptionMetadata.b(a);
            a.ac("GeographicShapeSeriesBaseBase", GeographicShapeSeriesBaseBaseDescriptionMetadata.a);
        }
    }
    GeographicShapeSeriesBaseBaseDescriptionMetadata.$t = markType(GeographicShapeSeriesBaseBaseDescriptionMetadata, 'GeographicShapeSeriesBaseBaseDescriptionMetadata');
    GeographicShapeSeriesBaseBaseDescriptionMetadata.a = null;
    return GeographicShapeSeriesBaseBaseDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GeographicShapeSeriesBaseBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapSeriesHostDescriptionMetadata } from "./GeographicMapSeriesHostDescriptionMetadata";
/**
 * @hidden
 */
export let GeographicShapeSeriesBaseBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicShapeSeriesBaseBaseDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicShapeSeriesBaseBaseDescriptionMetadata.a == null) {
                GeographicShapeSeriesBaseBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicShapeSeriesBaseBaseDescriptionMetadata.c(GeographicShapeSeriesBaseBaseDescriptionMetadata.a);
            }
            if (a.k(GeographicShapeSeriesBaseBaseDescriptionMetadata.a)) {
                return;
            }
            a.ac(GeographicShapeSeriesBaseBaseDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMapSeriesHostDescriptionMetadata.c(a);
        }
        static d(a) {
            GeographicShapeSeriesBaseBaseDescriptionMetadata.b(a);
            a.ad("GeographicShapeSeriesBaseBase", GeographicShapeSeriesBaseBaseDescriptionMetadata.a);
        }
    }
    GeographicShapeSeriesBaseBaseDescriptionMetadata.$t = markType(GeographicShapeSeriesBaseBaseDescriptionMetadata, 'GeographicShapeSeriesBaseBaseDescriptionMetadata');
    GeographicShapeSeriesBaseBaseDescriptionMetadata.a = null;
    return GeographicShapeSeriesBaseBaseDescriptionMetadata;
})();
